@@ -170,7 +170,7 @@ class ZopeTestBrowser(DriverAPI):
         for name, value in field_values.items():
             element = self.find_by_name(name)
             control = element.first._control
-            if control.type in ['text', 'textarea']:
+            if control.type in ['text', 'textarea', 'password']:
                 control.value = value
             elif control.type == 'checkbox':
                 if value:
